@@ -243,8 +243,8 @@ sub parse ($$;$$) {
 				$self->parse(\$subcontent, $stash, $label): "";
 		}
 		elsif ($op eq "SET") {
-			while ($rest =~ s/^\s*(\w+)=(['"`]?)(.*?)\2//s) {
-				my ($name, $value) = ($1, $3);
+			while ($rest =~ s/^\s*(\w+)=(?:(['"`])(.*?)\2|(\S+))//s) {
+				my ($name, $value) = ($1, defined $3? $3: $4);
 				$stash->{$name} = $self->parse(\$value, $stash, $label);
 			}
 			$chunk = "";
